@@ -188,8 +188,8 @@ class Mat : public Base< eT, Mat<eT> >
   inline Mat& operator/=(const spdiagview<eT>& X);
   
   
-  arma_cold inline mat_injector<Mat> operator<<(const eT val);
-  arma_cold inline mat_injector<Mat> operator<<(const injector_end_of_row<>& x);
+  arma_deprecated inline mat_injector<Mat> operator<<(const eT val);
+  arma_deprecated inline mat_injector<Mat> operator<<(const injector_end_of_row<>& x);
   
   
   arma_inline       subview_row<eT> row(const uword row_num);
@@ -400,6 +400,11 @@ class Mat : public Base< eT, Mat<eT> >
   arma_inline arma_warn_unused       eT& operator() (const uword ii);
   arma_inline arma_warn_unused const eT& operator() (const uword ii) const;
   
+  #if defined(__cpp_multidimensional_subscript)
+  arma_inline arma_warn_unused       eT& operator[] (const uword in_row, const uword in_col);
+  arma_inline arma_warn_unused const eT& operator[] (const uword in_row, const uword in_col) const;
+  #endif
+  
   arma_inline arma_warn_unused       eT& at         (const uword in_row, const uword in_col);
   arma_inline arma_warn_unused const eT& at         (const uword in_row, const uword in_col) const;
   arma_inline arma_warn_unused       eT& operator() (const uword in_row, const uword in_col);
@@ -418,8 +423,9 @@ class Mat : public Base< eT, Mat<eT> >
   arma_inline arma_warn_unused bool is_square() const;
        inline arma_warn_unused bool is_finite() const;
   
-  inline arma_warn_unused bool has_inf() const;
-  inline arma_warn_unused bool has_nan() const;
+  inline arma_warn_unused bool has_inf()       const;
+  inline arma_warn_unused bool has_nan()       const;
+  inline arma_warn_unused bool has_nonfinite() const;
   
   inline arma_warn_unused bool is_sorted(const char* direction = "ascend")       const;
   inline arma_warn_unused bool is_sorted(const char* direction, const uword dim) const;
@@ -781,7 +787,7 @@ class Mat : public Base< eT, Mat<eT> >
   
   public:
   
-  #ifdef ARMA_EXTRA_MAT_PROTO
+  #if defined(ARMA_EXTRA_MAT_PROTO)
     #include ARMA_INCFILE_WRAP(ARMA_EXTRA_MAT_PROTO)
   #endif
   };
@@ -857,6 +863,11 @@ class Mat<eT>::fixed : public Mat<eT>
   arma_inline arma_warn_unused       eT& operator() (const uword i);
   arma_inline arma_warn_unused const eT& operator() (const uword i) const;
   
+  #if defined(__cpp_multidimensional_subscript)
+  arma_inline arma_warn_unused       eT& operator[] (const uword in_row, const uword in_col);
+  arma_inline arma_warn_unused const eT& operator[] (const uword in_row, const uword in_col) const;
+  #endif
+  
   arma_inline arma_warn_unused       eT& at         (const uword in_row, const uword in_col);
   arma_inline arma_warn_unused const eT& at         (const uword in_row, const uword in_col) const;
   arma_inline arma_warn_unused       eT& operator() (const uword in_row, const uword in_col);
